@@ -1,6 +1,6 @@
-Kmatrix <- function(model, modelterm, covariate=NULL, as.is=FALSE, prtnum=FALSE)
+Kmatrix <- function(model, modelterm, covariate=NULL, as.is=FALSE, covariateV=NULL, prtnum=FALSE)
 {
-   if (inherits(model, "mer") || inherits(model, "merMod")) {
+  if (inherits(model, "mer") || inherits(model, "merMod")) { 
     if(!lme4::isLMM(model) && !lme4::isGLMM(model))
       stop("Can't handle a nonlinear mixed model")
     thecall <- slot(model, "call")
@@ -15,7 +15,7 @@ Kmatrix <- function(model, modelterm, covariate=NULL, as.is=FALSE, prtnum=FALSE)
     thecall <- model$call
     contrasts <- attr(model.matrix(model), "contrasts")
   }else stop(paste("Can't handle an model of class", class(model)[1]))
-
+  
   cov.reduce <- function(x, name) mean(x)
   
   fac.reduce <- function(coefs, lev) apply(coefs, 2, mean) 
@@ -42,12 +42,12 @@ Kmatrix <- function(model, modelterm, covariate=NULL, as.is=FALSE, prtnum=FALSE)
   #eval(thecall$data, envir=envir)
   
   X <- model.frame(form, model.frame(model), 
-                  subset = eval(thecall$subset, enclos=envir),
-                  na.action = na.omit, drop.unused.levels = TRUE)			  
+                   subset = eval(thecall$subset, enclos=envir),
+                   na.action = na.omit, drop.unused.levels = TRUE)			  
   preddf <- X
   baselevs <- xlev <- matdat <- list()  
   all.var.names <- names(X)
-
+  
   for (xname in all.var.names) {
     obj <- X[[xname]]
     if (is.factor(obj)) {            
@@ -67,46 +67,51 @@ Kmatrix <- function(model, modelterm, covariate=NULL, as.is=FALSE, prtnum=FALSE)
       else baselevs[[xname]] <- cov.reduce(obj, xname)       
     }
   }
- 
+  
   covlevname <- setdiff(names(baselevs), c(names(xlev), coerced))
-
-  if ((!is.null(covariate) && !covariate%in%c("NULL", "")) && is.numeric(covariate)) baselevs[covlevname] <- as.list(covariate)
-  if ((!is.null(covariate) && !covariate%in%c("NULL", "")) && is.character(covariate) && covariate%in%covlevname)  {
-    if (as.is) baselevs[[covariate]] <- sort(unique(X[[covariate]]))
-	else baselevs[[covariate]] <- seq(min(X[[covariate]]), max(X[[covariate]]),length=50)
+  
+  if ((!is.null(covariate) && !unique(covariate%in%c("NULL", ""))) && is.numeric(covariate)) baselevs[covlevname] <- as.list(covariate)
+  if ((!is.null(covariate) && !unique(covariate%in%c("NULL", ""))) && is.character(covariate) && covariate%in%covlevname && length(covariate)==1)  {
+    if (as.is) {
+      baselevs[[covariate]] <- sort(unique(X[[covariate]]))
+    }else{ 
+      if ((!is.null(covariateV) && !unique(covariateV%in%c("NULL", ""))) && is.vector(covariateV)){
+        baselevs[[covariate]] <- covariateV
+      }else baselevs[[covariate]] <- seq(min(X[[covariate]]), max(X[[covariate]]),length=50)
+    }
   }
   if (all(length(covlevname)!=0, prtnum)) {
     cat("\n", "The predicted means are estimated at \n\n")
     print(round( unlist(baselevs[covlevname]), 4))
     cat("\n")
   }
-
+  
   # OK. Now make a grid of the factor levels of interest, along w/ covariate "at" values
   grid <- do.call("expand.grid", baselevs)
-
+  
   # add any matrices
   for (nm in names(matdat))
     grid[[nm]] <- matrix(rep(matdat[[nm]], each=nrow(grid)), nrow=nrow(grid))
-
+  
   # Now make a new dataset with just the factor combs and covariate values we want for prediction
   # WARNING -- This will overwrite X, so get anything you need from X BEFORE we get here
-   
+  
   m <- model.frame(Terms, grid, na.action = na.pass, xlev = xlev)
   X <- model.matrix(Terms, m, contrasts.arg = contrasts)
-
+  
   # All factors (excluding covariates)
   allFacs <- all.var.names
   
   ### Array of indexes for rows of X, organized by dimensions
   row.indexes <- array(seq_len(nrow(X)), sapply(baselevs, length))  
-
+  
   # convert a string to a formula
   form <- as.formula(paste("~",modelterm))
-
+  
   # These are the variables involved; and the label to use in the results
   facs <- all.vars(form)
-  if ((!is.null(covariate) && !covariate%in%c("NULL", "")) && all(is.character(covariate), !covariate%in%facs)) facs <- c(facs, covariate)   
-     
+  if ((!is.null(covariate) && !unique(covariate%in%c("NULL", ""))) && all(is.character(covariate), !covariate%in%facs)) facs <- c(facs, covariate)   
+  
   if (any(sapply(facs, function(nm) length(grep(nm, allFacs)) == 0)))
     stop(paste("Unknown factor(s) in specification:", paste(form, collapse=" ")))
   
